@@ -1,12 +1,12 @@
 
 /*
  *  agUtils.c
- *  $Id: agUtils.c,v 1.35 2003/05/31 22:59:15 bkorb Exp $
+ *  $Id: agUtils.c,v 4.3 2005/01/24 00:00:30 bkorb Exp $
  *  This is the main routine for autogen.
  */
 
 /*
- *  AutoGen copyright 1992-2003 Bruce Korb
+ *  AutoGen copyright 1992-2005 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -25,8 +25,11 @@
  *             Boston,  MA  02111-1307, USA.
  */
 
-STATIC void addSysEnv( char* pzEnvName );
-STATIC tCC* skipQuote( tCC* pzQte );
+/* = = = START-STATIC-FORWARD = = = */
+/* static forward declarations maintained by :mkfwd */
+static tCC*
+skipQuote( tCC* pzQte );
+/* = = = END-STATIC-FORWARD = = = */
 
 #ifndef HAVE_STRLCPY
 size_t
@@ -57,7 +60,7 @@ strlcpy( char* dest, tCC* src, size_t n )
 #endif
 
 
-EXPORT char*
+LOCAL char*
 aprf( const char* pzFmt, ... )
 {
     char* pz;
@@ -78,39 +81,9 @@ aprf( const char* pzFmt, ... )
 }
 
 
-EXPORT void
+LOCAL void
 doOptions( int arg_ct, char** arg_vec )
 {
-    void ag_init( void );
-    /*
-     *  Initialize all the Scheme functions.
-     */
-    ag_init();
-    pzLastScheme = zSchemeInit;
-    ag_scm_c_eval_string_from_file_line( zSchemeInit, "directive.h",
-                                         SCHEME_INIT_LINE );
-#ifndef scm_t_port
-    {
-        tSCC zInitRest[] =
-            "(add-hook! before-error-hook error-source-line)\n"
-            "(use-modules (ice-9 stack-catch))";
-        pzLastScheme = zInitRest;
-        ag_scm_c_eval_string_from_file_line( zInitRest, __FILE__, __LINE__-3 );
-    }
-#endif
-    if (OPT_VALUE_TRACE > TRACE_NOTHING) {
-        tSCC zBT[] = "(debug-enable 'backtrace)";
-        pzLastScheme = zBT;
-        ag_scm_c_eval_string_from_file_line( zBT, __FILE__, __LINE__ - 2 );
-    }
-    pzLastScheme = NULL;
-
-    procState = PROC_STATE_OPTIONS;
-    /*
-     *  Set the last resort search directory first (lowest priority)
-     */
-    SET_OPT_TEMPL_DIRS( "$$/../share/autogen" );
-
     /*
      *  Advance the argument counters and pointers past any
      *  command line options
@@ -154,7 +127,7 @@ doOptions( int arg_ct, char** arg_vec )
      *  IF we do not have a base-name option, then we compute some value
      */
     if (! HAVE_OPT( BASE_NAME )) do {
-        char* pz;
+        tCC*  pz;
         char* pzD;
 
         if (! ENABLED_OPT( DEFINITIONS )) {
@@ -194,14 +167,17 @@ doOptions( int arg_ct, char** arg_vec )
      *  IF we have some defines to put in our environment, ...
      */
     if (HAVE_OPT( DEFINE )) {
-        int        ct  = STACKCT_OPT(  DEFINE );
-        char**     ppz = STACKLST_OPT( DEFINE );
+        int     ct  = STACKCT_OPT(  DEFINE );
+        tCC**   ppz = STACKLST_OPT( DEFINE );
 
         do  {
-            char* pz = *(ppz++);
+            tCC* pz = *(ppz++);
             /*
              *  IF there is no associated value,  THEN set it to '1'.
              *  There are weird problems with empty defines.
+             *  FIXME:  we loose track of this memory.  Don't know what to do,
+             *  really, there is no good recovery mechanism for environment
+             *  data.
              */
             if (strchr( pz, '=' ) == NULL) {
                 size_t siz = strlen( pz )+3;
@@ -215,98 +191,23 @@ doOptions( int arg_ct, char** arg_vec )
             /*
              *  Now put it in the environment
              */
-            putenv( pz );
+            putenv( (char*)pz );
         } while (--ct > 0);
     }
-
-    {
-        char z[ 128 ] = "__autogen__";
-#if defined( HAVE_POSIX_SYSINFO )
-        static const int nm[] = {
-            SI_SYSNAME, SI_HOSTNAME, SI_ARCHITECTURE, SI_HW_PROVIDER,
-#ifdef      SI_PLATFORM
-            SI_PLATFORM,
-#endif
-            SI_MACHINE };
-        int ix;
-        long sz;
-        char* pz = z+2;
-
-        addSysEnv( z );
-        for (ix = 0; ix < sizeof(nm)/sizeof(nm[0]); ix++) {
-            sz = sysinfo( nm[ix], z+2, sizeof( z ) - 2);
-            if (sz > 0) {
-                sz += 2;
-                while (z[sz-1] == NUL)  sz--;
-                strcpy( z + sz, "__" );
-                addSysEnv( z );
-            }
-        }
-
-#elif defined( HAVE_UNAME_SYSCALL )
-        struct utsname unm;
-
-        addSysEnv( z );
-        if (uname( &unm ) != 0) {
-            fprintf( stderr, "Error %d (%s) making uname(2) call\n",
-                     errno, strerror( errno ));
-            exit( EXIT_FAILURE );
-        }
-
-        sprintf( z+2, "%s__", unm.sysname );
-        addSysEnv( z );
-
-        sprintf( z+2, "%s__", unm.machine );
-        addSysEnv( z );
-
-        sprintf( z+2, "%s__", unm.nodename );
-        addSysEnv( z );
-#else
-
-        addSysEnv( z );
-#endif
-    }
 }
 
 
-STATIC void
-addSysEnv( char* pzEnvName )
-{
-    tSCC zFmt[] = "%s=1";
-    int i = 2;
-
-    for (;;) {
-        if (isupper( pzEnvName[i] ))
-            pzEnvName[i] = tolower( pzEnvName[i] );
-        else if (! isalnum( pzEnvName[i] ))
-            pzEnvName[i] = '_';
-
-        if (pzEnvName[ ++i ] == NUL)
-            break;
-    }
-    if (getenv( pzEnvName ) == NULL) {
-        char* pz;
-
-        if (OPT_VALUE_TRACE > TRACE_NOTHING)
-            fprintf( pfTrace, "Adding ``%s'' to environment\n", pzEnvName );
-        pz = aprf( zFmt, pzEnvName );
-        TAGMEM( pz, "Added environment var" );
-        putenv( pz );
-    }
-}
-
-
-EXPORT tCC*
+LOCAL tCC*
 getDefine( tCC* pzDefName )
 {
-    char**  ppz;
+    tCC**   ppz;
     int     ct;
     if (HAVE_OPT( DEFINE )) {
         ct  = STACKCT_OPT(  DEFINE );
         ppz = STACKLST_OPT( DEFINE );
 
         while (ct-- > 0) {
-            char* pz   = *(ppz++);
+            tCC*  pz   = *(ppz++);
             char* pzEq = strchr( pz, '=' );
             int   res;
 
@@ -325,7 +226,7 @@ getDefine( tCC* pzDefName )
 }
 
 
-EXPORT unsigned int
+LOCAL unsigned int
 doEscapeChar( tCC* pzIn, char* pRes )
 {
     unsigned int  res = 1;
@@ -443,7 +344,7 @@ doEscapeChar( tCC* pzIn, char* pRes )
  *  The quote character is whatever character the argument
  *  is pointing at when this procedure is called.
  */
-EXPORT char*
+LOCAL char*
 spanQuote( char* pzQte )
 {
     char  q = *pzQte;          /*  Save the quote character type */
@@ -494,7 +395,7 @@ spanQuote( char* pzQte )
  *  The quote character is whatever character the argument
  *  is pointing at when this procedure is called.
  */
-STATIC tCC*
+static tCC*
 skipQuote( tCC* pzQte )
 {
     char  q = *pzQte++;        /*  Save the quote character type */
@@ -539,7 +440,7 @@ skipQuote( tCC* pzQte )
 }
 
 
-EXPORT tCC*
+LOCAL tCC*
 skipScheme( tCC* pzSrc,  tCC* pzEnd )
 {
     int  level = 0;
@@ -564,7 +465,7 @@ skipScheme( tCC* pzSrc,  tCC* pzEnd )
 }
 
 
-EXPORT tCC*
+LOCAL tCC*
 skipExpression( tCC* pzSrc, size_t len )
 {
     tCC* pzEnd = pzSrc + len;
