@@ -1,12 +1,12 @@
 
 /*
  *  autogen.c
- *  $Id: autogen.c,v 1.47 2003/05/24 02:40:43 bkorb Exp $
+ *  $Id: autogen.c,v 4.5 2005/01/26 01:10:55 bkorb Exp $
  *  This is the main routine for autogen.
  */
 
 /*
- *  AutoGen copyright 1992-2003 Bruce Korb
+ *  AutoGen copyright 1992-2005 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -31,21 +31,36 @@ tSCC zClientInput[] = "client-input";
 tSCC* apzStateName[] = { STATE_TABLE };
 #undef _State_
 
-STATIC sigjmp_buf  abendJumpEnv;
+static sigjmp_buf  abendJumpEnv;
+typedef void (sighandler_proc_t)( int sig );
+static sighandler_proc_t ignoreSignal, abendSignal;
 
-/*
- *  Local procedures
- */
-STATIC void signalSetup( void );
-STATIC void abendSignal( int sig );
-STATIC void doneCheck( void );
-STATIC void inner_main( int argc, char** argv );
-STATIC void signalExit( int sig );
+/* = = = START-STATIC-FORWARD = = = */
+/* static forward declarations maintained by :mkfwd */
+static void
+inner_main( int argc, char** argv );
 
-STATIC void
+static void
+signalExit( int sig );
+
+static void
+abendSignal( int sig );
+
+static void
+ignoreSignal( int sig );
+
+static void
+doneCheck( void );
+
+static void
+signalSetup( sighandler_proc_t* chldHandler,
+             sighandler_proc_t* dfltHandler );
+/* = = = END-STATIC-FORWARD = = = */
+
+static void
 inner_main( int argc, char** argv )
 {
-    doOptions( argc, argv );
+    initialize( argc, argv );
 
     procState = PROC_STATE_LOAD_DEFS;
     readDefines();
@@ -84,15 +99,14 @@ main( int    argc,
             signalExit( signo );
     }
 
-    signalSetup();
+    signalSetup( ignoreSignal, abendSignal );
 
     gh_enter( argc, argv, inner_main );
     /* NOT REACHED */
     return 0;
 }
 
-
-STATIC void
+static void
 signalExit( int sig )
 {
     tSCC zErr[] = "AutoGen aborting on signal %d (%s) in state %s\n";
@@ -146,7 +160,8 @@ signalExit( int sig )
         fprintf( stderr, zAt, pzFl, line, pzFn, fnCd );
     }
 
-    exit( sig + 128 );
+    signalSetup( SIG_DFL, SIG_DFL );
+    abort();
 }
 
 
@@ -154,7 +169,7 @@ signalExit( int sig )
  *  abendSignal catches signals we abend on.  The "siglongjmp" goes back
  *  to the real "main()" procedure and it will call "signalExit()", above.
  */
-STATIC void
+static void
 abendSignal( int sig )
 {
     siglongjmp( abendJumpEnv, sig );
@@ -167,7 +182,7 @@ abendSignal( int sig )
  *  Therefore, always in all programs set it to call a procedure.
  *  The "wait(3)" call will do magical things, but will not override SIGIGN.
  */
-STATIC void
+static void
 ignoreSignal( int sig )
 {
 #ifdef DEBUG_ENABLED
@@ -180,7 +195,7 @@ ignoreSignal( int sig )
 /*
  *  This is called during normal exit processing.
  */
-STATIC void
+static void
 doneCheck( void )
 {
     tSCC zErr[] =
@@ -288,13 +303,12 @@ doneCheck( void )
 }
 
 
+LOCAL void
+ag_abend_at( tCC* pzMsg
 #ifdef DEBUG_ENABLED
-EXPORT void
-ag_abend_at( tCC* pzMsg, tCC* pzFile, int line )
-#else
-EXPORT void
-ag_abend( tCC* pzMsg )
+    , tCC* pzFile, int line
 #endif
+    )
 {
     if (*pzOopsPrefix != NUL) {
         fputs( pzOopsPrefix, stderr );
@@ -333,13 +347,19 @@ ag_abend( tCC* pzMsg )
 }
 
 
-STATIC void
-signalSetup( void )
+static void
+signalSetup( sighandler_proc_t* chldHandler,
+             sighandler_proc_t* dfltHandler )
 {
     struct sigaction  sa;
-    int    sigNo = 1;
-
+    int    sigNo  = 1;
+#ifdef SIGRTMIN
+    const int maxSig = SIGRTMIN-1;
+#else
+    const int maxSig = NSIG;
+#endif
     atexit( doneCheck );
+
     sa.sa_flags   = 0;
     sigemptyset( &sa.sa_mask );
 
@@ -358,7 +378,7 @@ signalSetup( void )
 #  define SIGCHLD SIGCLD
 #endif
         case SIGCHLD:
-            sa.sa_handler = ignoreSignal;
+            sa.sa_handler = chldHandler;
             break;
 
             /*
@@ -387,11 +407,21 @@ signalSetup( void )
             sa.sa_handler = SIG_IGN;
             break;
 
+#ifdef DAEMON_ENABLED
+# error DAEMON-ization of AutoGen is not ready for prime time
+        case SIGHUP:
+            if (HAVE_OPT( DAEMON )) {
+                sa.sa_handler = handleSighup;
+                break;
+            }
+            /* FALLTHROUGH */
+#endif
+
         default:
-            sa.sa_handler = abendSignal;
+            sa.sa_handler = dfltHandler;
         }
         sigaction( sigNo,  &sa, NULL );
-    } while (++sigNo < NSIG);
+    } while (++sigNo < maxSig);
 }
 
 #ifndef HAVE_STRFTIME
