@@ -1,13 +1,13 @@
 /*  
  *  EDIT THIS FILE WITH CAUTION  (cgi-fsm.c)
  *  
- *  It has been AutoGen-ed  Tuesday May 18, 2004 at 08:49:08 PM PDT
+ *  It has been AutoGen-ed  Saturday February  5, 2005 at 08:27:43 AM PST
  *  From the definitions    cgi.def
  *  and the template file   fsm
  *
  *  Automated Finite State Machine
  *
- *  Copyright (c) 2001-2004  by  Bruce Korb
+ *  Copyright (c) 2001-2005  by  Bruce Korb
  *
  *  AutoFSM is free software copyrighted by Bruce Korb.
  *  
@@ -46,9 +46,6 @@
 /* START === USER HEADERS === DO NOT CHANGE THIS COMMENT */
 
 #include "autogen.h"
-#ifdef DEBUG_ENABLED
-#  define DEBUG
-#endif
 
 /* END   === USER HEADERS === DO NOT CHANGE THIS COMMENT */
 
@@ -241,7 +238,8 @@ cgi_run_fsm(
             nxtSt = CGI_ST_INVALID;
             trans = CGI_TR_INVALID;
         } else {
-            const t_cgi_transition* pTT = cgi_trans_table[ cgi_state ] + trans_evt;
+            const t_cgi_transition* pTT =
+            cgi_trans_table[ cgi_state ] + trans_evt;
             nxtSt = firstNext = pTT->next_state;
             trans = pTT->transition;
         }
@@ -330,4 +328,11 @@ cgi_run_fsm(
     }
     return cgi_state;
 }
-/* end of cgi-fsm.c */
+/*
+ * Local Variables:
+ * mode: C
+ * c-file-style: "stroustrup"
+ * tab-width: 4
+ * indent-tabs-mode: nil
+ * End:
+ * end of cgi-fsm.c */
