@@ -1,12 +1,12 @@
 
 /*
- *  $Id: defLex.c,v 1.43 2004/10/07 16:03:58 bkorb Exp $
+ *  $Id: defLex.c,v 4.4 2005/01/24 00:00:31 bkorb Exp $
  *  This module scans the template variable declarations and passes
  *  tokens back to the parser.
  */
 
 /*
- *  AutoGen copyright 1992-2004 Bruce Korb
+ *  AutoGen copyright 1992-2005 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -54,17 +54,29 @@ int    aKeywordTkn[] = { KEYWORD_TABLE };
 
 #define SET_LIT_TKN(t) lastToken = DP_EV_LIT_ ## t; *(pCurCtx->pzScan++) = NUL;
 
-STATIC void  loadScheme( void );
-STATIC void  alist_to_autogen_def( void );
-STATIC char* assembleName( char* pzScan, te_dp_event* pRetVal );
-STATIC char* assembleString( char* pzScan );
-STATIC char* assembleHereString( char* pzScan );
+/* = = = START-STATIC-FORWARD = = = */
+/* static forward declarations maintained by :mkfwd */
+static void
+loadScheme( void );
+
+static void
+alist_to_autogen_def( void );
+
+static char*
+assembleName( char* pzScan, te_dp_event* pRetVal );
+
+static char*
+assembleHereString( char* pzScan );
+
+static char*
+assembleString( char* pzScan );
+/* = = = END-STATIC-FORWARD = = = */
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  *
  *   LEXICAL SCANNER
  */
-EXPORT te_dp_event
+LOCAL te_dp_event
 yylex( void )
 {
     lastToken = DP_EV_INVALID;
@@ -109,7 +121,6 @@ scanAgain:
         {
             tScanCtx* pCX = pCurCtx;
             pCurCtx = pCurCtx->pCtx;
-            AGFREE( (void*)pCX->pzFileName );
             pCX->pCtx = pDoneCtx;
             pDoneCtx  = pCX;
         }
@@ -260,7 +271,7 @@ scanAgain:
 NUL_error:
 
     AG_ABEND( aprf( zErrMsg, pzProg, "unterminated quote in definition",
-                    pCurCtx->pzFileName, pCurCtx->lineNo ));
+                    pCurCtx->pzCtxFname, pCurCtx->lineNo ));
     return DP_EV_INVALID;
 
 lex_done:
@@ -284,7 +295,7 @@ lex_done:
 }
 
 
-EXPORT void
+LOCAL void
 yyerror( char* s )
 {
     tSCC zErrTkn[] = "%s:  ``%s''\n";
@@ -314,12 +325,12 @@ yyerror( char* s )
                     "\t[[...<error-text>]] %s\n\n"
                     "Likely causes:  a mismatched quote, a value that needs "
                     "quoting,\n\t\tor a missing semi-colon\n",
-                    s, pCurCtx->pzFileName, pCurCtx->lineNo, pz,
+                    s, pCurCtx->pzCtxFname, pCurCtx->lineNo, pz,
                     pCurCtx->pzScan ));
 }
 
 
-STATIC void
+static void
 loadScheme( void )
 {
     char*    pzText    = pCurCtx->pzScan;
@@ -335,7 +346,7 @@ loadScheme( void )
     *pzEnd = NUL;
     procState = PROC_STATE_GUILE_PRELOAD;
     res = ag_scm_c_eval_string_from_file_line(
-        pzText, pCurCtx->pzFileName, pCurCtx->lineNo );
+        pzText, pCurCtx->pzCtxFname, pCurCtx->lineNo );
     procState = PROC_STATE_LOAD_DEFS;
     *pzEnd = endCh;
 
@@ -362,7 +373,7 @@ loadScheme( void )
  *  process a single scheme expression, yielding text that gets processed
  *  into AutoGen definitions.
  */
-STATIC void
+static void
 alist_to_autogen_def( void )
 {
     tSCC   zSchemeText[] = "Scheme Computed Definitions";
@@ -391,7 +402,7 @@ alist_to_autogen_def( void )
      */
     procState = PROC_STATE_GUILE_PRELOAD;
     res = ag_scm_c_eval_string_from_file_line(
-        pzText, pCurCtx->pzFileName, pCurCtx->lineNo );
+        pzText, pCurCtx->pzCtxFname, pCurCtx->lineNo );
 
     /*
      *  The result *must* be a string, or we choke.
@@ -417,7 +428,7 @@ alist_to_autogen_def( void )
     /*
      *  Set up the rest of the context structure
      */
-    AGDUPSTR( pCtx->pzFileName, zSchemeText, "scheme text" );
+    AGDUPSTR( pCtx->pzCtxFname, zSchemeText, "scheme text" );
     pCtx->pzScan = \
     pCtx->pzData = (char*)(pCtx+1);
     pCtx->lineNo = 0;
@@ -438,7 +449,7 @@ alist_to_autogen_def( void )
  *  It may be a number, a name, a keyword or garbage.
  *  Figure out which.
  */
-STATIC char*
+static char*
 assembleName( char* pzScan, te_dp_event* pRetVal )
 {
     /*
@@ -502,7 +513,7 @@ assembleName( char* pzScan, te_dp_event* pRetVal )
             if (pz == (unsigned char*)pzScan)
                 AG_ABEND( aprf( "%s Error: Invalid input char '%c' "
                                 "in %s on line %d\n", pzProg, *pzScan,
-                                pCurCtx->pzFileName, pCurCtx->lineNo ));
+                                pCurCtx->pzCtxFname, pCurCtx->lineNo ));
 
             *pRetVal = DP_EV_VAR_NAME;
         } else {
@@ -549,7 +560,7 @@ assembleName( char* pzScan, te_dp_event* pRetVal )
  *  A quoted string has been found.
  *  Find the end of it and compress any escape sequences.
  */
-STATIC char*
+static char*
 assembleHereString( char* pzScan )
 {
     ag_bool  trimTabs = AG_FALSE;
@@ -571,7 +582,7 @@ assembleHereString( char* pzScan )
     while (isspace( *pzScan )) {
         if (*pzScan++ == '\n')
             AG_ABEND( aprf( zErrMsg, pzProg, "HereString missing the mark",
-                            pCurCtx->pzFileName, pCurCtx->lineNo ));
+                            pCurCtx->pzCtxFname, pCurCtx->lineNo ));
     }
 
     /*
@@ -583,13 +594,13 @@ assembleHereString( char* pzScan )
             if (++markLen >= sizeof(zMark))
                 AG_ABEND( aprf( zErrMsg, pzProg, "HereString mark "
                                 STR( MAX_HEREMARK_LEN ) " or more chars",
-                                pCurCtx->pzFileName, pCurCtx->lineNo ));
+                                pCurCtx->pzCtxFname, pCurCtx->lineNo ));
 
             *(pz++) = *(pzScan++);
         }
         if (markLen == 0)
             AG_ABEND( aprf( zErrMsg, pzProg, "HereString missing the mark",
-                            pCurCtx->pzFileName, pCurCtx->lineNo ));
+                            pCurCtx->pzCtxFname, pCurCtx->lineNo ));
         *pz = NUL;
     }
 
@@ -602,11 +613,12 @@ assembleHereString( char* pzScan )
     pzScan = strchr( pzScan, '\n' );
     if (pzScan == NULL)
         AG_ABEND( aprf( zErrMsg, pzProg, "Unterminated HereString",
-                        pCurCtx->pzFileName, pCurCtx->lineNo ));
+                        pCurCtx->pzCtxFname, pCurCtx->lineNo ));
 
     /*
      *  And skip the first new line + conditionally skip tabs
      */
+    pCurCtx->lineNo++;
     pzScan++;
 
     if (trimTabs)
@@ -628,7 +640,7 @@ assembleHereString( char* pzScan )
 
             case NUL:
                 AG_ABEND( aprf( zErrMsg, pzProg, "Unterminated HereString",
-                                pCurCtx->pzFileName, pCurCtx->lineNo ));
+                                pCurCtx->pzCtxFname, pCurCtx->lineNo ));
             }
         } lineDone:;
 
@@ -652,7 +664,7 @@ assembleHereString( char* pzScan )
  *  A quoted string has been found.
  *  Find the end of it and compress any escape sequences.
  */
-STATIC char*
+static char*
 assembleString( char* pzScan )
 {
     char  q = *(pzScan++);
