@@ -1,13 +1,13 @@
 /*  
  *  EDIT THIS FILE WITH CAUTION  (defParse-fsm.c)
  *  
- *  It has been AutoGen-ed  Friday December 31, 2004 at 08:18:57 PM PST
+ *  It has been AutoGen-ed  Saturday February  5, 2005 at 08:27:44 AM PST
  *  From the definitions    defParse.def
  *  and the template file   fsm
  *
  *  Automated Finite State Machine
  *
- *  Copyright (c) 2001-2004  by  Bruce Korb
+ *  Copyright (c) 2001-2005  by  Bruce Korb
  *
  *  AutoFSM is free software copyrighted by Bruce Korb.
  *  
@@ -576,8 +576,8 @@ dp_do_tpl_name(
     if (rootDefCtx.pDefs == NULL) {
         tSCC   zBogus[] = "@BOGUS@";
         static tDefEntry seed = {
-            NULL, NULL, NULL, NULL, (char*)zBogus, VALTYP_BLOCK, 0,
-            { NULL } };
+            NULL, NULL, NULL, NULL, (char*)zBogus, 0, { NULL },
+            (char*)zBogus, 0, VALTYP_BLOCK };
 
         rootDefCtx.pDefs = &seed;
 
@@ -612,7 +612,8 @@ dp_run_fsm( void )
             nxtSt = DP_ST_INVALID;
             pT    = dp_do_invalid;
         } else {
-            const t_dp_transition* pTT = dp_trans_table[ dp_state ] + trans_evt;
+            const t_dp_transition* pTT =
+            dp_trans_table[ dp_state ] + trans_evt;
             nxtSt = firstNext = pTT->next_state;
             pT    = pTT->trans_proc;
         }
