@@ -1,15 +1,15 @@
 
 /*
- *  Time-stamp:      "2004-08-30 19:09:50 bkorb"
+ *  Time-stamp:      "2005-01-23 15:31:08 bkorb"
  *
- *  autoopts.h  $Id: autoopts.h,v 4.1 2005/01/01 00:12:40 bkorb Exp $
+ *  autoopts.h  $Id: autoopts.h,v 4.5 2005/01/24 00:00:35 bkorb Exp $
  *
  *  This file defines all the global structures and special values
  *  used in the automated option processing library.
  */
 
 /*
- *  Automated Options copyright 1992-2004 Bruce Korb
+ *  Automated Options copyright 1992-2005 Bruce Korb
  *
  *  Automated Options is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -87,6 +87,8 @@ typedef int tDirection;
 #define PROCESSING(d)     ((d)>0)
 #define PRESETTING(d)     ((d)<0)
 
+#define ISNAMECHAR( c )    (isalnum(c) || ((c) == '_') || ((c) == '-'))
+
 /*
  *  Procedure success codes
  *
@@ -259,7 +261,7 @@ typedef struct {
  *  the client will provide a callback for that purpose.
  */
 #undef DO_TRANSLATIONS
-#include "usage-txt.h"
+#include "autoopts/usage-txt.h"
 
 /*
  *  File pointer for usage output
@@ -269,48 +271,8 @@ extern FILE* option_usage_fp;
 extern tOptProc doVersion, doPagedUsage, doLoadOpt;
 
 #define LOCAL static
-#ifdef AUTOOPTS_INTERNAL
-/* === LOCAL PROCEDURES === */
+#include "proto.h"
 
-/* autoopts.c */
-static tSuccess
-handleOption( tOptions* pOpts, tOptState* pOptState );
-
-static tSuccess
-longOptionFind( tOptions* pOpts, char* pzOptName, tOptState* pOptState );
-
-static tSuccess
-shortOptionFind( tOptions* pOpts, tUC optValue, tOptState* pOptState );
-
-static tSuccess
-doImmediateOpts( tOptions* pOpts );
-
-static tSuccess
-doRegularOpts( tOptions* pOpts );
-
-
-/* environment.c */
-static void
-doPrognameEnv( tOptions* pOpts, teEnvPresetType type );
-
-static void
-doEnvPresets( tOptions* pOpts, teEnvPresetType type );
-
-
-/* load.c */
-static void
-filePreset(
-    tOptions*     pOpts,
-    const char*   pzFileName,
-    int           direction );
-
-
-/* sort.c */
-static void
-optionSort( tOptions* pOpts );
-
-/* === END LOCALS === */
-#endif /* GUILE_OPTIONS */
 #endif /* AUTOGEN_AUTOOPTS_H */
 /*
  * Local Variables:
