@@ -1,6 +1,6 @@
 
 /*
- *  $Id: enumeration.c,v 4.1 2005/01/01 00:12:40 bkorb Exp $
+ *  $Id: enumeration.c,v 4.3 2005/01/24 00:00:35 bkorb Exp $
  *
  *   Automated Options Paged Usage module.
  *
@@ -9,7 +9,7 @@
  */
 
 /*
- *  Automated Options copyright 1992-2004 Bruce Korb
+ *  Automated Options copyright 1992-2005 Bruce Korb
  *
  *  Automated Options is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -51,27 +51,27 @@
  * If you do not wish that, delete this exception notice.
  */
 
-/* === STATIC PROCS === */
-STATIC void
+tSCC*  pz_enum_err_fmt;
+
+/* = = = START-STATIC-FORWARD = = = */
+/* static forward declarations maintained by :mkfwd */
+static void
 enumError(
     tOptions* pOpts,
     tOptDesc* pOD,
     tCC**     paz_names,
     int       name_ct );
 
-STATIC uintptr_t
+static uintptr_t
 findName(
     tCC*          pzName,
     tOptions*     pOpts,
     tOptDesc*     pOD,
     tCC**         paz_names,
     unsigned int  name_ct );
+/* = = = END-STATIC-FORWARD = = = */
 
-/* === END STATIC PROCS === */
-
-tSCC*  pz_enum_err_fmt;
-
-STATIC void
+static void
 enumError(
     tOptions* pOpts,
     tOptDesc* pOD,
@@ -169,7 +169,7 @@ enumError(
 }
 
 
-STATIC uintptr_t
+static uintptr_t
 findName(
     tCC*          pzName,
     tOptions*     pOpts,
