@@ -1,12 +1,12 @@
 
 /*
- *  $Id: guileopt.c,v 1.15 2004/01/01 20:06:00 bkorb Exp $
+ *  $Id: guileopt.c,v 4.4 2005/01/24 00:00:35 bkorb Exp $
  *
  *  This module will export the option values to the Guile environment.
  */
 
 /*
- *  Automated Options copyright 1992-2003 Bruce Korb
+ *  Automated Options copyright 1992-2005 Bruce Korb
  *
  *  Automated Options is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -51,11 +51,9 @@
 #include <stdio.h>
 #include <guile/gh.h>
 
+#include "autoopts/options.h"
 #include "autoopts.h"
 
-/* === STATIC PROCS === */
-/* === END STATIC PROCS === */
-
 /*=export_func  export_options_to_guile
  * what:  put the option state into Guile symbols
  * private:
