@@ -1,6 +1,6 @@
 
 /*
- *  $Id: load.c,v 1.2 2004/01/01 20:06:00 bkorb Exp $
+ *  $Id: load.c,v 4.6 2005/02/04 04:24:45 bkorb Exp $
  *
  *  This file contains the routines that deal with processing text strings
  *  for options, either from a NUL-terminated string passed in or from an
@@ -8,7 +8,7 @@
  */
 
 /*
- *  Automated Options copyright 1992-2003 Bruce Korb
+ *  Automated Options copyright 1992-2005 Bruce Korb
  *
  *  Automated Options is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -50,15 +50,15 @@
  * If you do not wish that, delete this exception notice.
  */
 
-/* === STATIC PROCS === */
-STATIC void
+/* = = = START-STATIC-FORWARD = = = */
+/* static forward declarations maintained by :mkfwd */
+static void
 loadOptionLine(
     tOptions*  pOpts,
     tOptState* pOS,
     char*      pzLine,
     tDirection direction );
-
-/* === END STATIC PROCS === */
+/* = = = END-STATIC-FORWARD = = = */
 
 /*=export_func  optionMakePath
  * private:
@@ -71,18 +71,42 @@ loadOptionLine(
  *
  * ret-type: ag_bool
  * ret-desc: AG_TRUE if the name was handled, otherwise AG_FALSE.
+ *           If the name does not start with ``$'', then it is handled
+ *           simply by copying the input name to the output buffer.
  *
  * doc:
- *  This routine does environment variable expansion if the first character
- *  is a ``$''.  If it starts with two dollar characters, then the path
- *  is relative to the location of the executable.
+ *
+ *  This routine will copy the @code{pzName} input name into the @code{pzBuf}
+ *  output buffer, carefully not exceeding @code{bufSize} bytes.  If the
+ *  first character of the input name is a @code{'$'} character, then there
+ *  is special handling:
+ *  @*
+ *  @code{$$} is replaced with the directory name of the @code{pzProgPath},
+ *  searching @code{$PATH} if necessary.
+ *  @*
+ *  @code{$NAME} is replaced by the contents of the @code{NAME} environment
+ *  variable.
+ *
+ *  Please note: both @code{$$} and @code{$NAME} must be at the start of the
+ *     @code{pzName} string and must either be the entire string or be followed
+ *     by the @code{'/'} character.
+ *
+ * err:  @code{AG_FALSE} is returned if:
+ *       @*
+ *       @bullet{} @code{$$} is not the full string and
+ *                 the next character is not '/'.
+ *       @*
+ *       @bullet{} @code{$NAME} is not the full string and
+ *                 the next character is not '/'.
+ *       @*
+ *       @bullet{} @code{NAME} is not a known environment variable
 =*/
 ag_bool
 optionMakePath(
-    char*    pzBuf,
-    int      bufSize,
-    tCC*     pzName,
-    tCC*     pzProgPath )
+    char*   pzBuf,
+    int     bufSize,
+    tCC*    pzName,
+    tCC*    pzProgPath )
 {
     if (bufSize <= strlen( pzName ))
         return AG_FALSE;
@@ -91,7 +115,7 @@ optionMakePath(
      *  IF not an environment variable, just copy the data
      */
     if (*pzName != '$') {
-        strcpy( pzBuf, pzName );
+        strncpy( pzBuf, pzName, bufSize );
         return AG_TRUE;
     }
 
@@ -101,8 +125,8 @@ optionMakePath(
      *  with the path to the executable and append a "/" character.
      */
     if (pzName[1] == '$') {
-        tCC*  pzPath;
-        tCC*  pz;
+        tCC*    pzPath;
+        tCC*    pz;
 
         switch (pzName[2]) {
         case '/':
@@ -157,6 +181,13 @@ optionMakePath(
 
         memcpy( pzBuf, pzPath, (pz - pzPath)+1 );
         strcpy( pzBuf + (pz - pzPath) + 1, pzName );
+
+        /*
+         *  If the "pzPath" path was gotten from "pathfind()", then it was
+         *  allocated and we need to deallocate it.
+         */
+        if (pzPath != pzProgPath)
+             free( (void*)pzPath );
     }
 
     /*
@@ -192,11 +223,22 @@ optionMakePath(
         sprintf( pzBuf, "%s%s", pzDir, pzName );
     }
 
+#ifdef HAVE_REALPATH
+    {
+        char z[ PATH_MAX+1 ];
+
+        if (realpath( pzBuf, z ) == NULL)
+            return AG_FALSE;
+
+        strcpy( pzBuf, z );
+    }
+#endif
+
     return AG_TRUE;
 }
 
 
-STATIC void
+static void
 loadOptionLine(
     tOptions*  pOpts,
     tOptState* pOS,
@@ -211,16 +253,25 @@ loadOptionLine(
         char* pz = pzLine;
         while (  (! isspace( *pz ))
               && (*pz != NUL)
-              && (*pz != '=' )  ) pz++;
+              && (*pz != '=' )
+              && (*pz != ':' )  ) pz++;
 
         /*
-         *  IF we exited because we found either a space char or an '=',
-         *  THEN terminate the name (clobbering either a space or '=')
+         *  IF we exited because we found a character other than NUL
+         *  THEN terminate the name (clobbering our scan stop character)
          *       and scan over any more white space that follows.
          */
         if (*pz != NUL) {
+            int stopped_on_space = (isspace(*pz));
             *pz++ = NUL;
-            while (isspace( *pz )) pz++;
+            while (isspace(*pz))   pz++;
+
+            if (  stopped_on_space
+               && ((*pz == '=') || (*pz == ':'))  )  {
+
+                while (isspace(*(++pz)))   ;
+
+            }
         }
 
         /*
@@ -326,7 +377,7 @@ loadOptionLine(
 /*
  *  filePreset
  *
- *  Load a file containing presetting information (an RC file).
+ *  Load a file containing presetting information (a configuration file).
  */
 LOCAL void
 filePreset(
@@ -447,10 +498,9 @@ filePreset(
  *
  * doc:
  *
- * This is a user callable routine for setting options from, for
- * example, the contents of a file that they read in.
- * Only one option may appear in the text.  It will be treated
- * as a normal (non-preset) option.
+ * This is a client program callable routine for setting options from, for
+ * example, the contents of a file that they read in.  Only one option may
+ * appear in the text.  It will be treated as a normal (non-preset) option.
  *
  * When passed a pointer to the option struct and a string, it will
  * find the option named by the first token on the string and set
