@@ -1,6 +1,6 @@
 
 /*
- *  $Id: pgusage.c,v 2.15 2003/04/21 03:27:50 bkorb Exp $
+ *  $Id: pgusage.c,v 4.3 2005/01/24 00:00:37 bkorb Exp $
  *
  *   Automated Options Paged Usage module.
  *
@@ -9,7 +9,7 @@
  */
 
 /*
- *  Automated Options copyright 1992-2003 Bruce Korb
+ *  Automated Options copyright 1992-2005 Bruce Korb
  *
  *  Automated Options is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -53,14 +53,19 @@
 
 tePagerState pagerState = PAGER_STATE_INITIAL;
 
-/*
+/*=export_func  doPagedUsage
+ * private:
+ *
+ * what:  Decipher a boolean value
+ * arg:   + tOptions* + pOpts    + program options descriptor +
+ * arg:   + tOptDesc* + pOptDesc + the descriptor for this arg +
+ *
+ * doc:
  *  Run the usage output through a pager.
  *  This is very handy if it is very long.
- */
+=*/
 void
-doPagedUsage( pOptions, pOD )
-    tOptions* pOptions;
-    tOptDesc* pOD;
+doPagedUsage( tOptions* pOptions, tOptDesc* pOD )
 {
     static pid_t     my_pid;
     char zPageUsage[ 1024 ];
@@ -113,7 +118,7 @@ doPagedUsage( pOptions, pOD )
         /*
          *  Use the "more(1)" program if "PAGER" has not been defined
          */
-        if (pzPager == (char*)NULL)
+        if (pzPager == NULL)
             pzPager = "more";
 
         /*
