@@ -1,6 +1,6 @@
 
 /*
- *  $Id: putshell.c,v 2.26 2004/07/22 02:46:22 bkorb Exp $
+ *  $Id: putshell.c,v 4.3 2005/01/24 00:00:37 bkorb Exp $
  *
  *  This module will interpret the options set in the tOptions
  *  structure and print them to standard out in a fashion that
@@ -8,7 +8,7 @@
  */
 
 /*
- *  Automated Options copyright 1992-2004 Bruce Korb
+ *  Automated Options copyright 1992-2005 Bruce Korb
  *
  *  Automated Options is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -50,11 +50,17 @@
  * If you do not wish that, delete this exception notice.
  */
 
+/* = = = START-STATIC-FORWARD = = = */
+/* static forward declarations maintained by :mkfwd */
+static void
+putQuotedStr( tCC* pzStr );
+/* = = = END-STATIC-FORWARD = = = */
+
 /*
  *  Make sure embedded single quotes come out okay.  The initial quote has
  *  been emitted and the closing quote will be upon return.
  */
-STATIC void
+static void
 putQuotedStr( tCC* pzStr )
 {
     /*
