@@ -1,12 +1,12 @@
 
-/*  $Id: version.c,v 2.15 2003/04/21 03:27:51 bkorb Exp $
+/*  $Id: version.c,v 4.3 2005/01/24 00:00:37 bkorb Exp $
  *
  *  This module implements the default usage procedure for
  *  Automated Options.  It may be overridden, of course.
  */
 
 static const char zAOV[] =
-    "Automated Options version %s, copyright (c) 1999-2003 Bruce Korb\n";
+    "Automated Options version %s, copyright (c) 1999-2005 Bruce Korb\n";
 
 /*  Automated Options is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -48,19 +48,33 @@ static const char zAOV[] =
  * If you do not wish that, delete this exception notice.
  */
 
-tSCC zBadArg[] =
-"ERROR: version option argument '%c' invalid.  Use:\n\
-\t'v' - version only\n\
-\t'c' - version and copyright\n\
-\t'n' - version and copyright notice\n";
+/* = = = START-STATIC-FORWARD = = = */
+/* static forward declarations maintained by :mkfwd */
+static void
+printVersion( tOptions* pOpts, tOptDesc* pOD, FILE* fp );
+/* = = = END-STATIC-FORWARD = = = */
+
+/*=export_func  optionVersion
+ *
+ * what:     return the compiled AutoOpts version number
+ * ret_type: const char*
+ * ret_desc: the version string in constant memory
+ * doc:
+ *  Returns the full version string compiled into the library.
+ *  The returned string cannot be modified.
+=*/
+const char*
+optionVersion( void )
+{
+    static const char zVersion[] =
+        STR( AO_CURRENT.AO_REVISION );
+
+    return zVersion;
+}
 
-tSCC zBugRpt[] = "\nplease send bug reports to:  %s\n";
 
 static void
-printVersion( pOpts, pOD, fp )
-    tOptions*  pOpts;
-    tOptDesc*  pOD;
-    FILE*      fp;
+printVersion( tOptions* pOpts, tOptDesc* pOD, FILE* fp )
 {
     char swCh;
 
@@ -87,7 +101,7 @@ printVersion( pOpts, pOD, fp )
         }
         fprintf( fp, zAOV, optionVersion() );
         if (pOpts->pzBugAddr != NULL)
-            fprintf( fp, zBugRpt, pOpts->pzBugAddr );
+            fprintf( fp, zPlsSendBugs, pOpts->pzBugAddr );
         break;
 
     case 'n':
@@ -105,17 +119,27 @@ printVersion( pOpts, pOD, fp )
 
         fprintf( fp, zAOV, optionVersion() );
         if (pOpts->pzBugAddr != NULL)
-            fprintf( fp, zBugRpt, pOpts->pzBugAddr );
+            fprintf( fp, zPlsSendBugs, pOpts->pzBugAddr );
         break;
 
     default:
-        fprintf( stderr, zBadArg, swCh );
+        fprintf( stderr, zBadVerArg, swCh );
         exit( EXIT_FAILURE );
     }
 
     exit( EXIT_SUCCESS );
 }
 
+/*=export_func  doVersion
+ * private:
+ *
+ * what:  Print the program version
+ * arg:   + tOptions* + pOpts    + program options descriptor +
+ * arg:   + tOptDesc* + pOptDesc + the descriptor for this arg +
+ *
+ * doc:
+ *  This routine will print the version to stdout.
+=*/
 void
 doVersion( pOpts, pOD )
     tOptions*  pOpts;
@@ -124,6 +148,16 @@ doVersion( pOpts, pOD )
     printVersion( pOpts, pOD, stdout );
 }
 
+/*=export_func  doVersionStderr
+ * private:
+ *
+ * what:  Print the program version to stderr
+ * arg:   + tOptions* + pOpts    + program options descriptor +
+ * arg:   + tOptDesc* + pOptDesc + the descriptor for this arg +
+ *
+ * doc:
+ *  This routine will print the version to stderr.
+=*/
 void
 doVersionStderr( pOpts, pOD )
     tOptions*  pOpts;
