@@ -2,12 +2,12 @@
 ##  -*- Mode: shell-script -*-
 ## mklibsrc.sh --   make the libopts tear-off library source tarball
 ##
-## Time-stamp:      "2004-02-16 11:36:11 bkorb"
+## Time-stamp:      "2005-01-21 21:51:25 bkorb"
 ## Maintainer:      Bruce Korb <bkorb@gnu.org>
 ## Created:         Aug 20, 2002
 ##              by: bkorb
 ## ---------------------------------------------------------------------
-## $Id: mklibsrc.sh,v 1.21 2004/02/16 22:12:51 bkorb Exp $
+## $Id: mklibsrc.sh,v 4.5 2005/01/22 16:21:44 bkorb Exp $
 ## ---------------------------------------------------------------------
 ## Code:
 
@@ -23,28 +23,24 @@ tag=libopts-${AO_CURRENT}.${AO_REVISION}.${AO_AGE}
 
 cd ${top_builddir}/pkg
 [ ! -d ${tag} ] || rm -rf ${tag}
-mkdir ${tag}
-mkdir ${tag}/compat
+mkdir ${tag} ${tag}/compat ${tag}/autoopts
 
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
 #  WORKING IN SOURCE DIRECTORY
 #
-cd ${top_srcdir}/autoopts
-cp -f autoopts.c     \
-      boolean.c      \
-      enumeration.c  \
-      numeric.c      \
-      options.h      \
-      pgusage.c      \
-      restore.c      \
-      save.c         \
-      stack.c        \
-      streqv.h       \
-      usage.c        \
-      version.c      \
-  ${top_builddir}/pkg/${tag}/.
+cd ${top_builddir}/autoopts
+files=`fgrep '#include' libopts.c | \
+       sed 's,"$,,;s,#.*",,;/^streqvcmp.c$/d;/^autoopts.h$/d'`
+for f in libopts.c ${files}
+do
+  if test -f ${f}
+  then cp -f ${f} ${top_builddir}/pkg/${tag}/${f}
+  else cp -f ${top_srcdir}/autoopts/${f} ${top_builddir}/pkg/${tag}/${f}
+  fi
+done
 
+cd ${top_srcdir}/autoopts
 cp -f COPYING ${top_builddir}/pkg/${tag}/COPYING.lgpl
 
 sed '/#ifdef AUTOGEN_BUILD/,/#endif.* AUTOGEN_BUILD/d' streqvcmp.c > \
@@ -74,7 +70,8 @@ ${top_builddir}/agen5/autogen -L ${top_srcdir}/config --writable <<-	'_EOF_'
 	#include      libopts.def
 	_EOF_
 
-cat >> libopts.m4 <<-	EOMacro
+exec 3>> libopts.m4
+cat >&3 <<-	EOMacro
 
 	dnl @synopsis  LIBOPTS_CHECK
 	dnl
@@ -85,39 +82,38 @@ cat >> libopts.m4 <<-	EOMacro
 	AC_DEFUN([LIBOPTS_CHECK],[
 	`sed -n '/Check for standard headers/,/gen, pathfind/p' \
 	     ${top_srcdir}/configure.in`
+	EOMacro
 
+cat >&3 <<- \EOMacro
 	  AC_MSG_CHECKING([whether autoopts-config can be found])
 	  AC_ARG_WITH([autoopts-config],
         AC_HELP_STRING([--with-autoopts-config],
 	                   [specify the config-info script]),
-	    [lo_cv_with_autoopts_config=\${with_autoopts_config}],
+	    [lo_cv_with_autoopts_config=${with_autoopts_config}],
 	    AC_CACHE_CHECK([whether autoopts-config is specified],
 	       lo_cv_with_autoopts_config,
 	       lo_cv_with_autoopts_config=autoopts-config)
 	  ) # end of AC_ARG_WITH
 	  AC_CACHE_VAL([lo_cv_test_autoopts],[
-	    aoconfig=\${lo_cv_with_autoopts_config}
-	    lo_cv_test_autoopts=\`\${aoconfig} --libs\` 2> /dev/null
-	    if test \$? -ne 0
-	    then lo_cv_test_autoopts=no
-	    else if test -z "\$lo_cv_test_autoopts"
-	         then lo_cv_test_autoopts=yes
-	    fi ; fi
+	    aoconfig=${lo_cv_with_autoopts_config}
+	    lo_cv_test_autoopts=`${aoconfig} --libs` 2> /dev/null
+	    if test $? -ne 0 -o -z "${lo_cv_test_autoopts}"
+	    then lo_cv_test_autoopts=no ; fi
 	  ]) # end of CACHE_VAL
-	  AC_MSG_RESULT([\${lo_cv_test_autoopts}])
+	  AC_MSG_RESULT([${lo_cv_test_autoopts}])
 
-	  if test "X\${lo_cv_test_autoopts}" != Xno
+	  if test "X${lo_cv_test_autoopts}" != Xno
 	  then
-	    LIBOPTS_LDADD="\${lo_cv_test_autoopts}"
-	    LIBOPTS_CFLAGS="\`\${aoconfig} --cflags\`"
+	    LIBOPTS_LDADD="${lo_cv_test_autoopts}"
+	    LIBOPTS_CFLAGS="`${aoconfig} --cflags`"
 	    NEED_LIBOPTS_DIR=''
 	  else
-	    LIBOPTS_LDADD='\$(top_builddir)/libopts/libopts.la'
-	    LIBOPTS_CFLAGS='-I\$(top_srcdir)/libopts'
+	    LIBOPTS_LDADD='$(top_builddir)/libopts/libopts.la'
+	    LIBOPTS_CFLAGS='-I$(top_srcdir)/libopts'
 	    INVOKE_LIBOPTS_MACROS
 	    NEED_LIBOPTS_DIR=true
 	  fi
-	  AM_CONDITIONAL([NEED_LIBOPTS], [test -n "\${NEED_LIBOPTS_DIR}"])
+	  AM_CONDITIONAL([NEED_LIBOPTS], [test -n "${NEED_LIBOPTS_DIR}"])
 	  AC_SUBST(LIBOPTS_LDADD)
 	  AC_SUBST(LIBOPTS_CFLAGS)
 	  AC_CONFIG_FILES([libopts/Makefile])
@@ -129,13 +125,15 @@ cat >> libopts.m4 <<-	EOMacro
 sed s,'\${tag}',"${tag}",g ${top_srcdir}/pkg/libopts/README > README
 cp ${top_srcdir}/pkg/libopts/COPYING* .
 
+vers=${AO_CURRENT}:${AO_REVISION}:${AO_AGE}
 exec 3> Makefile.am
 cat >&3 <<-	EOMakefile
 	## LIBOPTS Makefile
-	EXTRA_DIST            = `echo COPYING*` compat
 	MAINTAINERCLEANFILES  = Makefile.in
 	lib_LTLIBRARIES       = libopts.la
-	libopts_la_SOURCES    = \\
+	libopts_la_SOURCES    = libopts.c
+	libopts_la_LDFLAGS    = -version-info ${AM_LDFLAGS} ${vers}
+	EXTRA_DIST            = `echo COPYING*` compat \\
 	EOMakefile
 
 cols="${top_builddir}/columns/columns -I4 --spread=1"
