@@ -1,3 +1,4 @@
+#line 1 "./printf.in"
 /*  -*- Mode: C -*-  */
 
 /* printf.in --- printf clone for argv arrays
@@ -99,6 +100,8 @@ typedef struct printf_info
   unsigned showsign:1;
   unsigned group:1;
   unsigned wide:1;
+
+  const union printf_arg *args;
 } printf_info;
 
 /**
@@ -136,7 +139,7 @@ typedef union printf_arg
   uintmax_t pa_u_long_long_int;
   float pa_float;
   double pa_double;
-  snv_long_double pa_long_double;
+  long double pa_long_double;
   const char *pa_string;
   const snv_wchar_t *pa_wstring;
   snv_constpointer pa_pointer;
@@ -159,7 +162,6 @@ typedef int printf_arginfo_function (struct printf_info *pparser, size_t n,
 /**
  * spec_entry:
  * @spec: the specifier character that was matched
- * @modifier_char: usually %FALSE, these specifiers aren't influenced by $ and cannot be overridden
  * @type: when @arg is NULL, the type of the only argument to the specifier
  * @fmt: the handler function to actually print the arguments to the specifier
  * @arg: the handler function to tell %printf about the types of the arguments to the specifier
@@ -170,7 +172,7 @@ typedef int printf_arginfo_function (struct printf_info *pparser, size_t n,
 typedef struct spec_entry
 {
   int spec;
-  int modifier_char;
+  int unused;  /* for binary compatibility */
   int type;
   printf_function *fmt;
   printf_arginfo_function *arg;
@@ -256,25 +258,7 @@ enum
     else count++; \
   } SNV_STMT_END
 
-/**
- * printf_generic_info:   
- * @pinfo: the current state information for the format
- * string parser.
- * @n: the number of available slots in the @argtypes array
- * @argtypes: the pointer to the first slot to be filled by the
- * function
- *
- * An example implementation of a %printf_arginfo_function, which
- * takes the basic type from the type given in the %spec_entry
- * and adds flags depending on what was parsed (e.g. %PA_FLAG_SHORT
- * is %pparser->is_short and so on).
- *
- * Return value:
- * Always 1.
- */
-extern int printf_generic_info (struct printf_info *const pinfo, size_t n, int *argtypes);
-
-
+#line 261 "./printf.in"
 /**
  * register_printf_function:  
  * @spec: the character which will trigger @func, cast to an unsigned int.
@@ -762,6 +746,43 @@ extern int snv_vasprintf (char **result, const char *format, va_list ap);
 extern int snv_asprintfv (char **result, const char *format, snv_constpointer const args[]);
 
 
+#line 262 "./printf.in"
+/**
+ * printf_generic_info:   
+ * @pinfo: the current state information for the format
+ * string parser.
+ * @n: the number of available slots in the @argtypes array
+ * @argtypes: the pointer to the first slot to be filled by the
+ * function
+ *
+ * An example implementation of a %printf_arginfo_function, which
+ * takes the basic type from the type given in the %spec_entry
+ * and adds flags depending on what was parsed (e.g. %PA_FLAG_SHORT
+ * is %pparser->is_short and so on).
+ *
+ * Return value:
+ * Always 1.
+ */
+extern int printf_generic_info (struct printf_info *const pinfo, size_t n, int *argtypes);
+
+
+/**
+ * printf_generic:   
+ * @stream: the stream (possibly a struct printfv_stream appropriately
+ * cast) on which to write output.
+ * @pinfo: the current state information for the format string parser.
+ * @args: the pointer to the first argument to be read by the handler
+ *
+ * An example implementation of a %printf_function, used to provide easy
+ * access to justification, width and precision options.
+ *
+ * Return value:
+ * The number of characters output.
+ **/
+extern int printf_generic (STREAM *stream, struct printf_info *const pinfo, union printf_arg const *args);
+
+
+#line 263 "./printf.in"
 
 /* If you don't want to use snprintfv functions for *all* of your string
    formatting API, then define COMPILING_SNPRINTFV_C and use the snv_
